@@ -1,6 +1,8 @@
 import re
 
-from .base import AccessDeniedOrDoesNotExistException, MetricsLayerBase
+
+from metrics_layer.core.exceptions import AccessDeniedOrDoesNotExistException, QueryError
+from .base import MetricsLayerBase
 from .field import Field
 from .set import Set
 
@@ -20,11 +22,36 @@ class View(MetricsLayerBase):
             return self.resolve_sql_table_name(self._definition["sql_table_name"], self.project.looker_env)
         return
 
+    @property
+    def identifiers(self):
+        if "identifiers" in self._definition:
+            return self._definition["identifiers"]
+        return []
+
+    @property
+    def model(self):
+        if "model_name" in self._definition:
+            return self.project.get_model(self._definition["model_name"])
+        elif "model" in self._definition:
+            return self._definition["model"]
+        return
+
+    @property
+    def week_start_day(self):
+        model = self.model
+        if model:
+            if model and model.week_start_day:
+                return model.week_start_day.lower()
+        return "monday"
+
+    def get_identifier(self, identifier_name: str):
+        return next((i for i in self.identifiers if i["name"] == identifier_name), None)
+
     def validate(self, definition: dict):
         required_keys = ["name", "fields"]
         for k in required_keys:
             if k not in definition:
-                raise ValueError(f"View missing required key {k}")
+                raise QueryError(f"View missing required key {k}")
 
     def printable_attributes(self):
         to_print = ["name", "type", "label", "group_label", "sql_table_name", "number_of_fields"]
@@ -41,19 +68,21 @@ class View(MetricsLayerBase):
         fields = self.fields(show_hidden=True)
         field_errors = []
 
-        if self.explore and self.default_date:
+        if self.model is None:
+            field_errors.append(
+                f"Could not find a model in view {self.name}. "
+                "Use the model_name property to specify the model."
+            )
+
+        if self.default_date:
             try:
-                # TODO make this more robust where it doesn't always require month to be present
                 if "." in self.default_date:
                     name = self.default_date
                 else:
                     name = f"{self.name}.{self.default_date}"
-                self.project.get_field(f"{name}_month", explore_name=self.explore.name)
-            except (AccessDeniedOrDoesNotExistException, ValueError):
-                field_errors.append(
-                    f"Default date {self.default_date} is unreachable in "
-                    f"view {self.name} in explore {self.explore.name}"
-                )
+                self.project.get_field_by_name(name)
+            except (AccessDeniedOrDoesNotExistException, QueryError):
+                field_errors.append(f"Default date {self.default_date} is unreachable in view {self.name}")
 
         for field in fields:
             field_errors.extend(field.collect_errors())
@@ -126,7 +155,7 @@ class View(MetricsLayerBase):
     def _resolve_dbt_ref_sql_table_name(self, sql_table_name: str):
         ref_arguments = sql_table_name[sql_table_name.find("ref(") + 4 : sql_table_name.find(")")]
         ref_value = ref_arguments.replace("'", "")
-        return self.project.resolve_dbt_ref(ref_value, self.name)
+        return self.project.resolve_dbt_ref(ref_value)
 
     @staticmethod
     def _resolve_conditional_sql_table_name(sql_table_name: str, looker_env: str):
@@ -137,7 +166,7 @@ class View(MetricsLayerBase):
         try:
             condition = next((cond for cond in conditions if cond.strip() == looker_env))
         except StopIteration:
-            raise ValueError(
+            raise QueryError(
                 f"""Your sql_table_name: '{sql_table_name}' contains a conditional and
                 we could not match that to the conditional value you passed: {looker_env}"""
             )
